from django.apps import AppConfig


class DjangoNextJSConfig(AppConfig):
    name = "django_nextjs"
    verbose_name = "Django NextJS"
